Class: Keepasshttp::KeyStore::External

Inherits:
Object
  • Object
show all
Defined in:
lib/keepasshttp/key_store.rb

Overview

Input the key and the id directly into the client so you can take care of the storage yourself.

Instance Method Summary collapse

Constructor Details

#initialize(key:, id:) ⇒ External

Returns a new instance of External.



10
11
12
# File 'lib/keepasshttp/key_store.rb', line 10

def initialize(key:, id:)
  @params = { key: key, id: id }
end

Instance Method Details

#available?Boolean

Returns:

  • (Boolean)


22
23
24
# File 'lib/keepasshttp/key_store.rb', line 22

def available?
  true
end

#loadObject



18
19
20
# File 'lib/keepasshttp/key_store.rb', line 18

def load
  @params
end

#save(*_args) ⇒ Object



14
15
16
# File 'lib/keepasshttp/key_store.rb', line 14

def save(*_args)
  false
end