Class: Keepasshttp::KeyStore::External
- Inherits:
-
Object
- Object
- Keepasshttp::KeyStore::External
- Defined in:
- lib/keepasshttp/key_store.rb
Overview
Input the key and the id directly into the client so you can take care of the storage yourself.
Instance Method Summary collapse
- #available? ⇒ Boolean
-
#initialize(key:, id:) ⇒ External
constructor
A new instance of External.
- #load ⇒ Object
- #save(*_args) ⇒ Object
Constructor Details
#initialize(key:, id:) ⇒ External
Returns a new instance of External.
10 11 12 |
# File 'lib/keepasshttp/key_store.rb', line 10 def initialize(key:, id:) @params = { key: key, id: id } end |
Instance Method Details
#available? ⇒ Boolean
22 23 24 |
# File 'lib/keepasshttp/key_store.rb', line 22 def available? true end |
#load ⇒ Object
18 19 20 |
# File 'lib/keepasshttp/key_store.rb', line 18 def load @params end |
#save(*_args) ⇒ Object
14 15 16 |
# File 'lib/keepasshttp/key_store.rb', line 14 def save(*_args) false end |